@@ -35,15 +35,15 @@
 #include "gupnp-didl-lite-createclass-private.h"
 #include "xml-util.h"
 
-G_DEFINE_TYPE (GUPnPDIDLLiteCreateClass,
-               gupnp_didl_lite_create_class,
-               G_TYPE_OBJECT);
-
 struct _GUPnPDIDLLiteCreateClassPrivate {
         xmlNode     *xml_node;
         GUPnPAVXMLDoc *xml_doc;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GUPnPDIDLLiteCreateClass,
+                            gupnp_didl_lite_create_class,
+                            G_TYPE_OBJECT);
+
 enum {
         PROP_0,
         PROP_XML_NODE,
@@ -149,7 +149,7 @@ gupnp_didl_lite_create_class_dispose (GObject *object)
 
         priv = GUPNP_DIDL_LITE_CREATE_CLASS (object)->priv;
 
-        g_clear_pointer (&priv->xml_doc, xml_doc_unref);
+        g_clear_pointer (&priv->xml_doc, av_xml_doc_unref);
 
         object_class = G_OBJECT_CLASS
                                    (gupnp_didl_lite_create_class_parent_class);
@@ -167,9 +167,6 @@ gupnp_didl_lite_create_class_class_init (GUPnPDIDLLiteCreateClassClass *klass)
         object_class->set_property = gupnp_didl_lite_create_class_set_property;
         object_class->dispose = gupnp_didl_lite_create_class_dispose;
 
-        g_type_class_add_private (klass,
-                                  sizeof (GUPnPDIDLLiteCreateClassPrivate));
-
         /**
          * GUPnPDIDLLiteCreateClass:xml-node:
          *
@@ -206,7 +203,7 @@ gupnp_didl_lite_create_class_class_init (GUPnPDIDLLiteCreateClassClass *klass)
                                     "XMLDoc",
                                     "The reference to XML document"
                                     " containing this object.",
-                                    xml_doc_get_type (),
+                                    av_xml_doc_get_type (),
                                     G_PARAM_WRITABLE |
                                     G_PARAM_CONSTRUCT_ONLY |
                                     G_PARAM_STATIC_NAME |
@@ -329,8 +326,8 @@ gupnp_didl_lite_create_class_get_include_derived
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CREATE_CLASS (create_class),
                               FALSE);
 
-        return xml_util_get_boolean_attribute (create_class->priv->xml_node,
-                                               "includeDerived");
+        return av_xml_util_get_boolean_attribute (create_class->priv->xml_node,
+                                                  "includeDerived");
 }
 
 /**
@@ -375,8 +372,8 @@ gupnp_didl_lite_create_class_get_friendly_name
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CREATE_CLASS (create_class),
                               NULL);
-        return xml_util_get_attribute_content (create_class->priv->xml_node,
-                                               "name");
+        return av_xml_util_get_attribute_content (create_class->priv->xml_node,
+                                                  "name");
 }
 
 /**
