@@ -25,6 +25,8 @@
 #ifndef __GUPNP_DIDL_LITE_OBJECT_PRIVATE_H__
 #define __GUPNP_DIDL_LITE_OBJECT_PRIVATE_H__
 
+#include "xml-util.h"
+
 #include <glib-object.h>
 #include <libxml/tree.h>
 
@@ -32,13 +34,13 @@ G_BEGIN_DECLS
 
 G_GNUC_INTERNAL GUPnPDIDLLiteObject *
 gupnp_didl_lite_object_new_from_xml     (xmlNode     *xml_node,
-                                         GUPnPXMLDoc *xml_doc,
+                                         GUPnPAVXMLDoc *xml_doc,
                                          xmlNs       *upnp_ns,
                                          xmlNs       *dc_ns,
                                          xmlNs       *dlna_ns,
                                          xmlNs       *pv_ns);
 
-G_GNUC_INTERNAL GUPnPXMLDoc *
+G_GNUC_INTERNAL GUPnPAVXMLDoc *
 gupnp_didl_lite_object_get_gupnp_xml_doc
                                         (GUPnPDIDLLiteObject *object);
 
