@@ -36,10 +36,6 @@
 #define DIDL_S_FILTER "dc:title,dc:creator,upnp:class,upnp:album,res,item," \
                       "container,dlna:lifetime"
 
-G_DEFINE_TYPE (GUPnPMediaCollection,
-               gupnp_media_collection,
-               G_TYPE_OBJECT);
-
 struct _GUPnPMediaCollectionPrivate {
         GUPnPDIDLLiteWriter *writer;
         GUPnPDIDLLiteObject *container;
@@ -48,6 +44,10 @@ struct _GUPnPMediaCollectionPrivate {
         char                *data;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GUPnPMediaCollection,
+                            gupnp_media_collection,
+                            G_TYPE_OBJECT);
+
 enum {
         PROP_0,
         PROP_AUTHOR,
@@ -89,7 +89,7 @@ on_container_available (GUPnPMediaCollection   *self,
         if (self->priv->container != NULL)
                 g_object_unref (self->priv->container);
 
-        self->priv->container = g_object_ref (container);
+        self->priv->container = GUPNP_DIDL_LITE_OBJECT (g_object_ref (container));
 }
 
 static void
@@ -284,8 +284,6 @@ gupnp_media_collection_class_init (GUPnPMediaCollectionClass *klass)
         object_class->constructed = gupnp_media_collection_constructed;
         object_class->dispose = gupnp_media_collection_dispose;
 
-        g_type_class_add_private (klass, sizeof (GUPnPMediaCollectionPrivate));
-
         /**
          * GUPnPMediaCollection:author:
          *
